agentle.mcp.resources.binary\_resources
=======================================

.. automodule:: agentle.mcp.resources.binary_resources

   
.. rubric:: Modules

.. autosummary::
   :toctree:
   :recursive:

   audio_files
   base64_convertible
   image
   pdfs
   video_files
